fn checked_offset_with_leapsecond(
lhs: &NaiveDateTime,
seconds: i32,
) -> Option<NaiveDateTime>Expand description
Shifts lhs by seconds, keeping a leap second representable.
fn checked_offset_with_leapsecond(
lhs: &NaiveDateTime,
seconds: i32,
) -> Option<NaiveDateTime>Shifts lhs by seconds, keeping a leap second representable.